# Generated by Django 3.0.7 on 2020-06-25 20:52

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
        ('Spades', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='event',
            name='user',
            field=models.ForeignKey(default=1, on_delete=django.db.models.deletion.CASCADE, to=settings.AUTH_USER_MODEL),
            preserve_default=False,
        ),
    ]



from django.contrib import admin
from django import forms
from .models import Event
from django.contrib.auth.models import User

import json

class EventAdminForm(forms.ModelForm):
    
    class Meta:
        model = Event
        fields = '__all__'
        widgets = {
            'info': forms.Textarea(attrs={
                                    'class': 'pretty',
                                    'disabled': True,
                                    'rows':1, 
                                    'cols':15
                                    })
        } 

class EventAdmin(admin.ModelAdmin):
    form = EventAdminForm
    list_display = ['name', 'created', 'last_updated', 'user',]
    readonly_fields = ['name', 'created', 'last_updated','user']
    date_hierarchy = 'created'

    fieldsets = (
        (
            None, {
                'fields':('name', 'created', 'last_updated','user','info')
            }
        ),
    )

    
    class Media:
        js = (
            'Spades/js/prettyjson.js', 
            'Spades/js/eventadmin.js', 
        )
        css = { 
            'all':('Spades/css/eventadmin.css',),
        } 

admin.site.register(Event, EventAdmin)





# Generated by Django 2.2 on 2020-02-14 16:13

from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='Event',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=255)),
                ('created', models.DateTimeField(auto_now_add=True)),
                ('last_updated', models.DateTimeField(auto_now=True)),
                ('info', models.TextField()),
            ],
            options={
                'ordering': ('-created',),
            },
        ),
    ]



from django.urls import reverse
from django.db.models import CharField
from django.db.models import DateTimeField
from django.db.models import TextField
from django.conf import settings
from django.contrib.contenttypes.fields import GenericForeignKey
from django.contrib.contenttypes.models import ContentType
from django.contrib.auth import get_user_model
from django.contrib.auth import models as auth_models
from django.db import models as models 
import json
from django.contrib.auth.models import User
from django.core.exceptions import ValidationError
from django.conf import settings



class Event(models.Model):
    # Fields
    name = models.CharField(max_length=255)
    created = models.DateTimeField(auto_now_add=True, editable=False)
    last_updated = models.DateTimeField(auto_now=True, editable=False)
    info = models.TextField()
    user = models.ForeignKey(
            settings.AUTH_USER_MODEL,
            on_delete=models.CASCADE,
            blank=True,null=True
        )

    class Meta:
        ordering = ('-created',)

    def __str__(self):
        return u'%s' % self.pk

    def get_absolute_url(self):
        return reverse('EventTracker_event_detail', args=(self.pk,))


    def get_update_url(self):
        return reverse('EventTracker_event_update', args=(self.pk,))

    # def user(self):
    #     j = json.loads(self.info)
    #     if 'User' in j:
    #         user = User.objects.get(id=j['User'])
    #         return user

    def save(self, *args, **kwargs):
        try:
            j = json.loads(self.info)
        except:
            raise ValidationError('Info needs to be of JSON format')


        super().save(*args, **kwargs)  






import unittest
from django.urls import reverse
from django.test import Client
from .models import Event
from django.contrib.auth.models import User
from django.contrib.auth.models import Group
from django.contrib.contenttypes.models import ContentType

def create_event(**kwargs):
    defaults = {}
    defaults["name"] = "name"
    defaults["info"] = '''{
                        "userId": 1,
                        "id": 1,
                        "title": "big title",
                        "completed": false
                        }''' 
    defaults.update(**kwargs)
    return Event.objects.create(**defaults)



class EventViewTest(unittest.TestCase):
    '''
    Tests for Event
    '''
    def setUp(self):
        self.client = Client()





# Generated by Django 3.1.6 on 2021-03-29 08:09

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
        ('Spades', '0002_event_user'),
    ]

    operations = [
        migrations.AlterField(
            model_name='event',
            name='user',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, to=settings.AUTH_USER_MODEL),
        ),
    ]
